==> prestashop_1.4.1.0.zip: prestashop/modules/blocklayered/de.php <==
<?php

global $_MODULE;
$_MODULE = array();
$_MODULE['<{blocklayered}prestashop>blocklayered_84241e458cdd5162745500a59a3680f3'] = 'Layered Navigation-Block';
$_MODULE['<{blocklayered}prestashop>blocklayered_2d08fa8e157fe3f1875402cbd98aee1b'] = 'Zeigt einen Block mit Layered Navigation-Filter an';
$_MODULE['<{blocklayered}prestashop>blocklayered_7ad3f384bcf30d783b5a6f6c810b4762'] = 'Layered Navigation Datanbank wurde erfolgreich initialisiert';
$_MODULE['<{blocklayered}prestashop>blocklayered_fe016d3b990c2a9dd72ab6b45892f2ae'] = 'Einstellungen erfolgreich gespeichert';
$_MODULE['<{blocklayered}prestashop>blocklayered_09da2b6f1217055bb22caa6ea08d9b80'] = 'Layered Navigation';
$_MODULE['<{blocklayered}prestashop>blocklayered_6b50913da72479e39aae61ec4739b09a'] = 'Dies ist die Beta-Version dieses Moduls, es wird in PrestaShop v1.4.1 verbessert werden';
$_MODULE['<{blocklayered}prestashop>blocklayered_f6fc27f63284329ab1391e19ec7d873a'] = '10 bevorstehende Verbesserungen in PrestaShop v1.4.1';
$_MODULE['<{blocklayered}prestashop>blocklayered_b77ae7b3f227f97fdbfbaee819c048d6'] = 'Echtzeit-Aktualisierung der Cache-Tabelle';
$_MODULE['<{blocklayered}prestashop>blocklayered_3cd881c5805a5564b080022968081652'] = 'Zusätzliche Filter (Preise, Gewicht)';
$_MODULE['<{blocklayered}prestashop>blocklayered_f67587ba40eff59a15796352c9037ddf'] = 'Fähigkeit, Filter nach Kategorie in der Modulkonfiguration zu verwalten ';
$_MODULE['<{blocklayered}prestashop>blocklayered_559175435fec02f846564385b20b98e2'] = 'Fähigkeit, Filtergruppen zu verbergen, die keine Werte und Filter-Werte mit 0 Produkten haben';
$_MODULE['<{blocklayered}prestashop>blocklayered_abb461f7d4d8271a12ceead064d13cd0'] = 'Statistik und Analyse';
$_MODULE['<{blocklayered}prestashop>blocklayered_6af4dd46928a781eda42b940d3394ca6'] = 'Produktsortierung & Paginierung verwalten ';
$_MODULE['<{blocklayered}prestashop>blocklayered_b4ecb2bd1ea5153550669329db53277d'] = 'Kontrolle zur Kategorie-Gruppentabelle hinzufügen';
$_MODULE['<{blocklayered}prestashop>blocklayered_d99bf479cc40101e28f1f0ba1bfb6150'] = 'SEO Links & Echtzeit URL einrichten (Fähigkeit, die URL jemandem zu geben)';
$_MODULE['<{blocklayered}prestashop>blocklayered_27c7b93d882068a1137a9350c7f1a132'] = 'Weitere Optionen zur Modul-Konfiguration hinzufügen';
$_MODULE['<{blocklayered}prestashop>blocklayered_fb8082696a8d7a40fa62ea0e89b18c32'] = 'Leistungsverbesserungen';
$_MODULE['<{blocklayered}prestashop>blocklayered_f4f70727dc34561dfde1a3c529b6205c'] = 'Einstellungen';
$_MODULE['<{blocklayered}prestashop>blocklayered_b17f3f4dcf653a5776792498a9b44d6a'] = 'Einstellungen aktualisieren';
$_MODULE['<{blocklayered}prestashop>blocklayered_7263de0a10ad25dfdadc44791c44fb1f'] = 'Cache-Initialisierung';
$_MODULE['<{blocklayered}prestashop>blocklayered_590af1487ee6c10871628c4e2a968f67'] = 'Wann müssen Sie den Cache initialisieren?';
$_MODULE['<{blocklayered}prestashop>blocklayered_f3ac6d10ce5508b543141ae9bce6294c'] = 'Bevor Sie dieses Modul zum ersten Mal benutzen';
$_MODULE['<{blocklayered}prestashop>blocklayered_c32735b7ba755d545ef36c5e5cd1f17e'] = 'Sie fügen hinzu / aktualisieren / löschen';
$_MODULE['<{blocklayered}prestashop>blocklayered_97e3d87f9cedf66eea7514ffe2f8d56c'] = 'eine Funktion oder einen Funktionswert';
$_MODULE['<{blocklayered}prestashop>blocklayered_7a5d52e91cda4e97b3776b23a9356918'] = 'eine Attribut-Gruppe oder einen Attribut-Wert';
$_MODULE['<{blocklayered}prestashop>blocklayered_5a1e99c9ae45729844784683d8c02379'] = 'Sie aktualisieren einen oder mehrere Funktionswerte für ein Produkt';
$_MODULE['<{blocklayered}prestashop>blocklayered_2875534393f5ef32e42d92c30e9dfda5'] = 'Achtung: Dies kann mehrere Minuten dauern.';
$_MODULE['<{blocklayered}prestashop>blocklayered_15aa842a19af51c2cf1ec631cdf8337a'] = 'Wenn Sie dies nicht tun, könnte dies Cache-Tabelle immer größer werden (d.h. weniger effizient), und all die neuen Möglichkeiten (Attribute, Funktionen) können Ihren Besuchern nicht angeboten werden.';
$_MODULE['<{blocklayered}prestashop>blocklayered_c64a069750ff8924b029b2206cabf3b2'] = 'Initialisieren Sie die Layered Navigation Datenbank';
$_MODULE['<{blocklayered}prestashop>blocklayered_af1b98adf7f686b84cd0b443e022b7a0'] = 'Kategorien';
$_MODULE['<{blocklayered}prestashop>blocklayered_9e2941b3c81256fac10392aaca4ccfde'] = 'Zustand';
$_MODULE['<{blocklayered}prestashop>blocklayered_03c2e7e41ffc181a4e84080b4710e81e'] = 'Neu';
$_MODULE['<{blocklayered}prestashop>blocklayered_019d1ca7d50cc54b995f60d456435e87'] = 'Gebraucht';
$_MODULE['<{blocklayered}prestashop>blocklayered_6da03a74721a0554b7143254225cc08a'] = 'Überholt';
$_MODULE['<{blocklayered}prestashop>blocklayered_faeaec9eda6bc4c8cb6e1a9156a858be'] = 'Verfügbarkeit';
$_MODULE['<{blocklayered}prestashop>blocklayered_fcebe56087b9373f15514831184fa572'] = 'Auf Lager';
$_MODULE['<{blocklayered}prestashop>blocklayered_2d25c72c1b18e562f6654fff8e11711e'] = 'Nicht verfügbar';
$_MODULE['<{blocklayered}prestashop>blocklayered_c0bd7654d5b278e65f21cf4e9153fdb4'] = 'Hersteller';
$_MODULE['<{blocklayered}prestashop>blocklayered_c32516babc5b6c47eb8ce1bfc223253c'] = 'Katalog';
$_MODULE['<{blocklayered}prestashop>blocklayered_1262d1b9fbffb3a8e85ac9e4b449e989'] = 'Aktivierte Filter:';
$_MODULE['<{blocklayered}prestashop>blocklayered_ea4788705e6873b424c65e91c2846b19'] = 'Abbrechen';
$_MODULE['<{blocklayered}prestashop>blocklayered_853ae90f0351324bd73ea615e6487517'] = ':';
$_MODULE['<{blocklayered}prestashop>blocklayered_8524de963f07201e5c086830d370797f'] = 'Lädt...';

==> prestashop_1.4.3.0.zip: prestashop/modules/blocklayered/de.php <==
<?php

global $_MODULE;
$_MODULE = array();
$_MODULE['<{blocklayered}prestashop>blocklayered_c32516babc5b6c47eb8ce1bfc223253c'] = 'Katalog';
$_MODULE['<{blocklayered}prestashop>blocklayered_1262d1b9fbffb3a8e85ac9e4b449e989'] = 'Aktivierte Filter:';
$_MODULE['<{blocklayered}prestashop>blocklayered_853ae90f0351324bd73ea615e6487517'] = ':';
$_MODULE['<{blocklayered}prestashop>blocklayered_ea4788705e6873b424c65e91c2846b19'] = 'Abbrechen';
$_MODULE['<{blocklayered}prestashop>blocklayered_87ba2ecc8b6915e8bd6f5089918229fd'] = 'Bereich';
$_MODULE['<{blocklayered}prestashop>blocklayered_8524de963f07201e5c086830d370797f'] = 'Lädt...';
$_MODULE['<{blocklayered}prestashop>blocklayered_84241e458cdd5162745500a59a3680f3'] = 'Layered Navigation-Block';
$_MODULE['<{blocklayered}prestashop>blocklayered_2d08fa8e157fe3f1875402cbd98aee1b'] = 'Zeigt einen Block mit Layered Navigation-Filter an';
$_MODULE['<{blocklayered}prestashop>blocklayered_7ad3f384bcf30d783b5a6f6c810b4762'] = 'Layered Navigation Datanbank wurde erfolgreich initialisiert';
$_MODULE['<{blocklayered}prestashop>blocklayered_fe016d3b990c2a9dd72ab6b45892f2ae'] = 'Einstellungen erfolgreich gespeichert';
$_MODULE['<{blocklayered}prestashop>blocklayered_09da2b6f1217055bb22caa6ea08d9b80'] = 'Layered Navigation';
$_MODULE['<{blocklayered}prestashop>blocklayered_382a0cf3c7ea26e9c7d0642d6d0ec07d'] = 'Das Modul ist noch in der Beta Version und wird weiter entwickelt';
$_MODULE['<{blocklayered}prestashop>blocklayered_016d6031144c99f759b36c5e00c79e91'] = '10 weitere Neuerungen';
$_MODULE['<{blocklayered}prestashop>blocklayered_b77ae7b3f227f97fdbfbaee819c048d6'] = 'Echtzeit-Aktualisierung der Cache-Tabelle';
$_MODULE['<{blocklayered}prestashop>blocklayered_3cd881c5805a5564b080022968081652'] = 'Zusätzliche Filter (Preise, Gewicht)';
$_MODULE['<{blocklayered}prestashop>blocklayered_f67587ba40eff59a15796352c9037ddf'] = 'Fähigkeit, Filter nach Kategorie in der Modulkonfiguration zu verwalten ';
$_MODULE['<{blocklayered}prestashop>blocklayered_559175435fec02f846564385b20b98e2'] = 'Fähigkeit, Filtergruppen zu verbergen, die keine Werte und Filter-Werte mit 0 Produkten haben';
$_MODULE['<{blocklayered}prestashop>blocklayered_abb461f7d4d8271a12ceead064d13cd0'] = 'Statistik und Analyse';
$_MODULE['<{blocklayered}prestashop>blocklayered_6af4dd46928a781eda42b940d3394ca6'] = 'Produktsortierung & Paginierung verwalten ';
$_MODULE['<{blocklayered}prestashop>blocklayered_b4ecb2bd1ea5153550669329db53277d'] = 'Kontrolle zur Kategorie-Gruppentabelle hinzufügen';
$_MODULE['<{blocklayered}prestashop>blocklayered_d99bf479cc40101e28f1f0ba1bfb6150'] = 'SEO Links & Echtzeit URL einrichten (Fähigkeit, die URL jemandem zu geben)';
$_MODULE['<{blocklayered}prestashop>blocklayered_27c7b93d882068a1137a9350c7f1a132'] = 'Weitere Optionen zur Modul-Konfiguration hinzufügen';
$_MODULE['<{blocklayered}prestashop>blocklayered_fb8082696a8d7a40fa62ea0e89b18c32'] = 'Leistungsverbesserungen';
$_MODULE['<{blocklayered}prestashop>blocklayered_f4f70727dc34561dfde1a3c529b6205c'] = 'Einstellungen';
$_MODULE['<{blocklayered}prestashop>blocklayered_b17f3f4dcf653a5776792498a9b44d6a'] = 'Einstellungen aktualisieren';
$_MODULE['<{blocklayered}prestashop>blocklayered_7263de0a10ad25dfdadc44791c44fb1f'] = 'Cache-Initialisierung';
$_MODULE['<{blocklayered}prestashop>blocklayered_d15ce73cbadfe1e806ee7abd08a7fe4d'] = 'Vor dem ersten Gebrauch bitte Cache initialisieren';
$_MODULE['<{blocklayered}prestashop>blocklayered_2875534393f5ef32e42d92c30e9dfda5'] = 'Achtung: Dies kann mehrere Minuten dauern.';
$_MODULE['<{blocklayered}prestashop>blocklayered_15aa842a19af51c2cf1ec631cdf8337a'] = 'Wenn Sie dies nicht tun, könnte dies Cache-Tabelle immer größer werden (d.h. weniger effizient), und all die neuen Möglichkeiten (Attribute, Funktionen) können Ihren Besuchern nicht angeboten werden.';
$_MODULE['<{blocklayered}prestashop>blocklayered_c64a069750ff8924b029b2206cabf3b2'] = 'Initialisieren Sie die Layered Navigation Datenbank';
$_MODULE['<{blocklayered}prestashop>blocklayered_af1b98adf7f686b84cd0b443e022b7a0'] = 'Kategorien';
$_MODULE['<{blocklayered}prestashop>blocklayered_9e2941b3c81256fac10392aaca4ccfde'] = 'Zustand';
$_MODULE['<{blocklayered}prestashop>blocklayered_03c2e7e41ffc181a4e84080b4710e81e'] = 'Neu';
$_MODULE['<{blocklayered}prestashop>blocklayered_019d1ca7d50cc54b995f60d456435e87'] = 'Gebraucht';
$_MODULE['<{blocklayered}prestashop>blocklayered_6da03a74721a0554b7143254225cc08a'] = 'Überholt';
$_MODULE['<{blocklayered}prestashop>blocklayered_faeaec9eda6bc4c8cb6e1a9156a858be'] = 'Verfügbarkeit';
$_MODULE['<{blocklayered}prestashop>blocklayered_fcebe56087b9373f15514831184fa572'] = 'Auf Lager';
$_MODULE['<{blocklayered}prestashop>blocklayered_2d25c72c1b18e562f6654fff8e11711e'] = 'Nicht verfügbar';
$_MODULE['<{blocklayered}prestashop>blocklayered_c0bd7654d5b278e65f21cf4e9153fdb4'] = 'Hersteller';
$_MODULE['<{blocklayered}prestashop>blocklayered_8c489d0946f66d17d73f26366a4bf620'] = 'Gewicht';

?>
